import { Pagination, Empty } from "antd";
import CourseCard from "./CourseCard";
import { CourseDto, Prisma } from "@nice/common";
import { api } from "@nice/client";
import { DefaultArgs } from "@prisma/client/runtime/library";
import { useEffect, useMemo, useState } from "react";
interface CourseListProps {
	params?: {
		page?: number;
		pageSize?: number;
		where?: Prisma.PostWhereInput;
		select?: Prisma.PostSelect<DefaultArgs>;
	};
}
interface CoursesPagnationProps {
	data: {
		items: CourseDto[];
		totalPages: number;
	};
	isLoading: boolean;
}
export default function CourseList({ params }: CourseListProps) {
	const [currentPage, setCurrentPage] = useState<number>(params?.page || 1);
	const { data, isLoading }: CoursesPagnationProps =
		api.post.findManyWithPagination.useQuery({
			...params,
			page: currentPage,
		});
	const totalPages = useMemo(() => {
		if (data && !isLoading) {
			return data?.totalPages;
		}
		return 1;
	}, [data, isLoading]);

	const courses = useMemo(() => {
		if (data && !isLoading) {
			return data?.items;
		}
		return [];
	}, [data, isLoading]);

	useEffect(() => {
		setCurrentPage(params?.page || 1);
	}, [params?.page]);
	function onPageChange(page: number, pageSize: number) {
		setCurrentPage(page);
		window.scrollTo({ top: 0, behavior: "smooth" });
	}
	return (
		<div className="space-y-6">
			{courses.length > 0 ? (
				<>
					<div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
						{courses.map((course) => (
							<CourseCard key={course.id} course={course} />
						))}
					</div>
					<div className="flex justify-center mt-8">
						<Pagination
							current={currentPage}
							total={totalPages}
							pageSize={params?.pageSize}
							onChange={onPageChange}
							showSizeChanger={false}
						/>
					</div>
				</>
			) : (
				<Empty description="暂无相关课程" />
			)}
		</div>
	);
}
